depends = ('ITKPyBase', 'ITKCommon', )
templates = (
  ('Sample', 'itk::Statistics::Sample', 'itkSampleFAD1', True, 'itk::FixedArray< double,1 >'),
  ('Sample', 'itk::Statistics::Sample', 'itkSampleFAF1', True, 'itk::FixedArray< float,1 >'),
  ('Sample', 'itk::Statistics::Sample', 'itkSampleFAUL1', True, 'itk::FixedArray< unsigned long,1 >'),
  ('Sample', 'itk::Statistics::Sample', 'itkSampleFAUS1', True, 'itk::FixedArray< unsigned short,1 >'),
  ('Sample', 'itk::Statistics::Sample', 'itkSampleFAUC1', True, 'itk::FixedArray< unsigned char,1 >'),
  ('Sample', 'itk::Statistics::Sample', 'itkSampleFASL1', True, 'itk::FixedArray< signed long,1 >'),
  ('Sample', 'itk::Statistics::Sample', 'itkSampleFASS1', True, 'itk::FixedArray< signed short,1 >'),
  ('Sample', 'itk::Statistics::Sample', 'itkSampleFASC1', True, 'itk::FixedArray< signed char,1 >'),
  ('Sample', 'itk::Statistics::Sample', 'itkSampleFAD2', True, 'itk::FixedArray< double,2 >'),
  ('Sample', 'itk::Statistics::Sample', 'itkSampleFAF2', True, 'itk::FixedArray< float,2 >'),
  ('Sample', 'itk::Statistics::Sample', 'itkSampleFAUL2', True, 'itk::FixedArray< unsigned long,2 >'),
  ('Sample', 'itk::Statistics::Sample', 'itkSampleFAUS2', True, 'itk::FixedArray< unsigned short,2 >'),
  ('Sample', 'itk::Statistics::Sample', 'itkSampleFAUC2', True, 'itk::FixedArray< unsigned char,2 >'),
  ('Sample', 'itk::Statistics::Sample', 'itkSampleFASL2', True, 'itk::FixedArray< signed long,2 >'),
  ('Sample', 'itk::Statistics::Sample', 'itkSampleFASS2', True, 'itk::FixedArray< signed short,2 >'),
  ('Sample', 'itk::Statistics::Sample', 'itkSampleFASC2', True, 'itk::FixedArray< signed char,2 >'),
  ('Sample', 'itk::Statistics::Sample', 'itkSampleFAD3', True, 'itk::FixedArray< double,3 >'),
  ('Sample', 'itk::Statistics::Sample', 'itkSampleFAF3', True, 'itk::FixedArray< float,3 >'),
  ('Sample', 'itk::Statistics::Sample', 'itkSampleFAUL3', True, 'itk::FixedArray< unsigned long,3 >'),
  ('Sample', 'itk::Statistics::Sample', 'itkSampleFAUS3', True, 'itk::FixedArray< unsigned short,3 >'),
  ('Sample', 'itk::Statistics::Sample', 'itkSampleFAUC3', True, 'itk::FixedArray< unsigned char,3 >'),
  ('Sample', 'itk::Statistics::Sample', 'itkSampleFASL3', True, 'itk::FixedArray< signed long,3 >'),
  ('Sample', 'itk::Statistics::Sample', 'itkSampleFASS3', True, 'itk::FixedArray< signed short,3 >'),
  ('Sample', 'itk::Statistics::Sample', 'itkSampleFASC3', True, 'itk::FixedArray< signed char,3 >'),
  ('Sample', 'itk::Statistics::Sample', 'itkSampleVF2', True, 'itk::Vector< float,2 >'),
  ('Sample', 'itk::Statistics::Sample', 'itkSampleVF3', True, 'itk::Vector< float,3 >'),
  ('Sample', 'itk::Statistics::Sample', 'itkSampleAF', True, 'itk::Array< float >'),
  ('Sample', 'itk::Statistics::Sample', 'itkSampleAD', True, 'itk::Array< double >'),
  ('Histogram', 'itk::Statistics::Histogram', 'itkHistogramF', True, 'float'),
  ('Histogram', 'itk::Statistics::Histogram', 'itkHistogramD', True, 'double'),
  ('SimpleDataObjectDecorator', 'itk::SimpleDataObjectDecorator', 'itkSimpleDataObjectDecoratorHF', False, 'itk::Statistics::Histogram< float > *'),
  ('SimpleDataObjectDecorator', 'itk::SimpleDataObjectDecorator', 'itkSimpleDataObjectDecoratorHD', False, 'itk::Statistics::Histogram< double > *'),
  ('ListSample', 'itk::Statistics::ListSample', 'itkListSampleVF2', True, 'itk::Vector< float,2 >'),
  ('ListSample', 'itk::Statistics::ListSample', 'itkListSampleVF3', True, 'itk::Vector< float,3 >'),
  ('MembershipFunctionBase', 'itk::Statistics::MembershipFunctionBase', 'itkMembershipFunctionBaseVF2', True, 'itk::Vector< float,2 >'),
  ('MembershipFunctionBase', 'itk::Statistics::MembershipFunctionBase', 'itkMembershipFunctionBaseVF3', True, 'itk::Vector< float,3 >'),
  ('KdTree', 'itk::Statistics::KdTree', 'itkKdTreeLSVF2', True, 'itk::Statistics::ListSample< itk::Vector< float,2 > >'),
  ('KdTree', 'itk::Statistics::KdTree', 'itkKdTreeLSVF3', True, 'itk::Statistics::ListSample< itk::Vector< float,3 > >'),
  ('KdTreeNode', 'itk::Statistics::KdTreeNode', 'itkKdTreeNodeLSVF2', False, 'itk::Statistics::ListSample< itk::Vector< float,2 > >'),
  ('KdTreeNode', 'itk::Statistics::KdTreeNode', 'itkKdTreeNodeLSVF3', False, 'itk::Statistics::ListSample< itk::Vector< float,3 > >'),
  ('DistanceMetric', 'itk::Statistics::DistanceMetric', 'itkDistanceMetricVF2', True, 'itk::Vector< float,2 >'),
  ('DistanceMetric', 'itk::Statistics::DistanceMetric', 'itkDistanceMetricVF3', True, 'itk::Vector< float,3 >'),
  ('EuclideanDistanceMetric', 'itk::Statistics::EuclideanDistanceMetric', 'itkEuclideanDistanceMetricVF2', True, 'itk::Vector< float,2 >'),
  ('EuclideanDistanceMetric', 'itk::Statistics::EuclideanDistanceMetric', 'itkEuclideanDistanceMetricVF3', True, 'itk::Vector< float,3 >'),
  ('HistogramToEntropyImageFilter', 'itk::HistogramToEntropyImageFilter', 'itkHistogramToEntropyImageFilterHFIF2', True, 'itk::Statistics::Histogram< float >, itk::Image< float,2 >'),
  ('HistogramToEntropyImageFilter', 'itk::HistogramToEntropyImageFilter', 'itkHistogramToEntropyImageFilterHDIF2', True, 'itk::Statistics::Histogram< double >, itk::Image< float,2 >'),
  ('HistogramToEntropyImageFilter', 'itk::HistogramToEntropyImageFilter', 'itkHistogramToEntropyImageFilterHFID2', True, 'itk::Statistics::Histogram< float >, itk::Image< double,2 >'),
  ('HistogramToEntropyImageFilter', 'itk::HistogramToEntropyImageFilter', 'itkHistogramToEntropyImageFilterHDID2', True, 'itk::Statistics::Histogram< double >, itk::Image< double,2 >'),
  ('HistogramToEntropyImageFilter', 'itk::HistogramToEntropyImageFilter', 'itkHistogramToEntropyImageFilterHFIF3', True, 'itk::Statistics::Histogram< float >, itk::Image< float,3 >'),
  ('HistogramToEntropyImageFilter', 'itk::HistogramToEntropyImageFilter', 'itkHistogramToEntropyImageFilterHDIF3', True, 'itk::Statistics::Histogram< double >, itk::Image< float,3 >'),
  ('HistogramToEntropyImageFilter', 'itk::HistogramToEntropyImageFilter', 'itkHistogramToEntropyImageFilterHFID3', True, 'itk::Statistics::Histogram< float >, itk::Image< double,3 >'),
  ('HistogramToEntropyImageFilter', 'itk::HistogramToEntropyImageFilter', 'itkHistogramToEntropyImageFilterHDID3', True, 'itk::Statistics::Histogram< double >, itk::Image< double,3 >'),
  ('HistogramToIntensityImageFilter', 'itk::HistogramToIntensityImageFilter', 'itkHistogramToIntensityImageFilterHFIF2', True, 'itk::Statistics::Histogram< float >, itk::Image< float,2 >'),
  ('HistogramToIntensityImageFilter', 'itk::HistogramToIntensityImageFilter', 'itkHistogramToIntensityImageFilterHDIF2', True, 'itk::Statistics::Histogram< double >, itk::Image< float,2 >'),
  ('HistogramToIntensityImageFilter', 'itk::HistogramToIntensityImageFilter', 'itkHistogramToIntensityImageFilterHFID2', True, 'itk::Statistics::Histogram< float >, itk::Image< double,2 >'),
  ('HistogramToIntensityImageFilter', 'itk::HistogramToIntensityImageFilter', 'itkHistogramToIntensityImageFilterHDID2', True, 'itk::Statistics::Histogram< double >, itk::Image< double,2 >'),
  ('HistogramToIntensityImageFilter', 'itk::HistogramToIntensityImageFilter', 'itkHistogramToIntensityImageFilterHFIF3', True, 'itk::Statistics::Histogram< float >, itk::Image< float,3 >'),
  ('HistogramToIntensityImageFilter', 'itk::HistogramToIntensityImageFilter', 'itkHistogramToIntensityImageFilterHDIF3', True, 'itk::Statistics::Histogram< double >, itk::Image< float,3 >'),
  ('HistogramToIntensityImageFilter', 'itk::HistogramToIntensityImageFilter', 'itkHistogramToIntensityImageFilterHFID3', True, 'itk::Statistics::Histogram< float >, itk::Image< double,3 >'),
  ('HistogramToIntensityImageFilter', 'itk::HistogramToIntensityImageFilter', 'itkHistogramToIntensityImageFilterHDID3', True, 'itk::Statistics::Histogram< double >, itk::Image< double,3 >'),
  ('HistogramToLogProbabilityImageFilter', 'itk::HistogramToLogProbabilityImageFilter', 'itkHistogramToLogProbabilityImageFilterHFIF2', True, 'itk::Statistics::Histogram< float >, itk::Image< float,2 >'),
  ('HistogramToLogProbabilityImageFilter', 'itk::HistogramToLogProbabilityImageFilter', 'itkHistogramToLogProbabilityImageFilterHDIF2', True, 'itk::Statistics::Histogram< double >, itk::Image< float,2 >'),
  ('HistogramToLogProbabilityImageFilter', 'itk::HistogramToLogProbabilityImageFilter', 'itkHistogramToLogProbabilityImageFilterHFID2', True, 'itk::Statistics::Histogram< float >, itk::Image< double,2 >'),
  ('HistogramToLogProbabilityImageFilter', 'itk::HistogramToLogProbabilityImageFilter', 'itkHistogramToLogProbabilityImageFilterHDID2', True, 'itk::Statistics::Histogram< double >, itk::Image< double,2 >'),
  ('HistogramToLogProbabilityImageFilter', 'itk::HistogramToLogProbabilityImageFilter', 'itkHistogramToLogProbabilityImageFilterHFIF3', True, 'itk::Statistics::Histogram< float >, itk::Image< float,3 >'),
  ('HistogramToLogProbabilityImageFilter', 'itk::HistogramToLogProbabilityImageFilter', 'itkHistogramToLogProbabilityImageFilterHDIF3', True, 'itk::Statistics::Histogram< double >, itk::Image< float,3 >'),
  ('HistogramToLogProbabilityImageFilter', 'itk::HistogramToLogProbabilityImageFilter', 'itkHistogramToLogProbabilityImageFilterHFID3', True, 'itk::Statistics::Histogram< float >, itk::Image< double,3 >'),
  ('HistogramToLogProbabilityImageFilter', 'itk::HistogramToLogProbabilityImageFilter', 'itkHistogramToLogProbabilityImageFilterHDID3', True, 'itk::Statistics::Histogram< double >, itk::Image< double,3 >'),
  ('HistogramToProbabilityImageFilter', 'itk::HistogramToProbabilityImageFilter', 'itkHistogramToProbabilityImageFilterHFIF2', True, 'itk::Statistics::Histogram< float >, itk::Image< float,2 >'),
  ('HistogramToProbabilityImageFilter', 'itk::HistogramToProbabilityImageFilter', 'itkHistogramToProbabilityImageFilterHDIF2', True, 'itk::Statistics::Histogram< double >, itk::Image< float,2 >'),
  ('HistogramToProbabilityImageFilter', 'itk::HistogramToProbabilityImageFilter', 'itkHistogramToProbabilityImageFilterHFID2', True, 'itk::Statistics::Histogram< float >, itk::Image< double,2 >'),
  ('HistogramToProbabilityImageFilter', 'itk::HistogramToProbabilityImageFilter', 'itkHistogramToProbabilityImageFilterHDID2', True, 'itk::Statistics::Histogram< double >, itk::Image< double,2 >'),
  ('HistogramToProbabilityImageFilter', 'itk::HistogramToProbabilityImageFilter', 'itkHistogramToProbabilityImageFilterHFIF3', True, 'itk::Statistics::Histogram< float >, itk::Image< float,3 >'),
  ('HistogramToProbabilityImageFilter', 'itk::HistogramToProbabilityImageFilter', 'itkHistogramToProbabilityImageFilterHDIF3', True, 'itk::Statistics::Histogram< double >, itk::Image< float,3 >'),
  ('HistogramToProbabilityImageFilter', 'itk::HistogramToProbabilityImageFilter', 'itkHistogramToProbabilityImageFilterHFID3', True, 'itk::Statistics::Histogram< float >, itk::Image< double,3 >'),
  ('HistogramToProbabilityImageFilter', 'itk::HistogramToProbabilityImageFilter', 'itkHistogramToProbabilityImageFilterHDID3', True, 'itk::Statistics::Histogram< double >, itk::Image< double,3 >'),
  ('HistogramToRunLengthFeaturesFilter', 'itk::Statistics::HistogramToRunLengthFeaturesFilter', 'itkHistogramToRunLengthFeaturesFilterHF', True, 'itk::Statistics::Histogram< float >'),
  ('HistogramToRunLengthFeaturesFilter', 'itk::Statistics::HistogramToRunLengthFeaturesFilter', 'itkHistogramToRunLengthFeaturesFilterHD', True, 'itk::Statistics::Histogram< double >'),
  ('HistogramToRunLengthFeaturesFilterEnums', 'itk::Statistics::HistogramToRunLengthFeaturesFilterEnums', 'itkHistogramToRunLengthFeaturesFilterEnums', False),
  ('HistogramToTextureFeaturesFilter', 'itk::Statistics::HistogramToTextureFeaturesFilter', 'itkHistogramToTextureFeaturesFilterHD', True, 'itk::Statistics::Histogram< double >'),
  ('HistogramToTextureFeaturesFilter', 'itk::Statistics::HistogramToTextureFeaturesFilter', 'itkHistogramToTextureFeaturesFilterHF', True, 'itk::Statistics::Histogram< float >'),
  ('HistogramToTextureFeaturesFilterEnums', 'itk::Statistics::HistogramToTextureFeaturesFilterEnums', 'itkHistogramToTextureFeaturesFilterEnums', False),
  ('ImageToHistogramFilter', 'itk::Statistics::ImageToHistogramFilter', 'itkImageToHistogramFilterIRGBUC2', True, 'itk::Image< itk::RGBPixel< unsigned char >,2 >'),
  ('ImageToHistogramFilter', 'itk::Statistics::ImageToHistogramFilter', 'itkImageToHistogramFilterIRGBUC3', True, 'itk::Image< itk::RGBPixel< unsigned char >,3 >'),
  ('ImageToHistogramFilter', 'itk::Statistics::ImageToHistogramFilter', 'itkImageToHistogramFilterIRGBAUC2', True, 'itk::Image< itk::RGBAPixel< unsigned char >,2 >'),
  ('ImageToHistogramFilter', 'itk::Statistics::ImageToHistogramFilter', 'itkImageToHistogramFilterIRGBAUC3', True, 'itk::Image< itk::RGBAPixel< unsigned char >,3 >'),
  ('ImageToHistogramFilter', 'itk::Statistics::ImageToHistogramFilter', 'itkImageToHistogramFilterIVF22', True, 'itk::Image< itk::Vector< float,2 >,2 >'),
  ('ImageToHistogramFilter', 'itk::Statistics::ImageToHistogramFilter', 'itkImageToHistogramFilterIVF23', True, 'itk::Image< itk::Vector< float,2 >,3 >'),
  ('ImageToHistogramFilter', 'itk::Statistics::ImageToHistogramFilter', 'itkImageToHistogramFilterIVF32', True, 'itk::Image< itk::Vector< float,3 >,2 >'),
  ('ImageToHistogramFilter', 'itk::Statistics::ImageToHistogramFilter', 'itkImageToHistogramFilterIVF33', True, 'itk::Image< itk::Vector< float,3 >,3 >'),
  ('ImageToHistogramFilter', 'itk::Statistics::ImageToHistogramFilter', 'itkImageToHistogramFilterIVF42', True, 'itk::Image< itk::Vector< float,4 >,2 >'),
  ('ImageToHistogramFilter', 'itk::Statistics::ImageToHistogramFilter', 'itkImageToHistogramFilterIVF43', True, 'itk::Image< itk::Vector< float,4 >,3 >'),
  ('ImageToHistogramFilter', 'itk::Statistics::ImageToHistogramFilter', 'itkImageToHistogramFilterICVF22', True, 'itk::Image< itk::CovariantVector< float,2 >,2 >'),
  ('ImageToHistogramFilter', 'itk::Statistics::ImageToHistogramFilter', 'itkImageToHistogramFilterICVF23', True, 'itk::Image< itk::CovariantVector< float,2 >,3 >'),
  ('ImageToHistogramFilter', 'itk::Statistics::ImageToHistogramFilter', 'itkImageToHistogramFilterICVF32', True, 'itk::Image< itk::CovariantVector< float,3 >,2 >'),
  ('ImageToHistogramFilter', 'itk::Statistics::ImageToHistogramFilter', 'itkImageToHistogramFilterICVF33', True, 'itk::Image< itk::CovariantVector< float,3 >,3 >'),
  ('ImageToHistogramFilter', 'itk::Statistics::ImageToHistogramFilter', 'itkImageToHistogramFilterICVF42', True, 'itk::Image< itk::CovariantVector< float,4 >,2 >'),
  ('ImageToHistogramFilter', 'itk::Statistics::ImageToHistogramFilter', 'itkImageToHistogramFilterICVF43', True, 'itk::Image< itk::CovariantVector< float,4 >,3 >'),
  ('ImageToHistogramFilter', 'itk::Statistics::ImageToHistogramFilter', 'itkImageToHistogramFilterISS2', True, 'itk::Image< signed short,2 >'),
  ('ImageToHistogramFilter', 'itk::Statistics::ImageToHistogramFilter', 'itkImageToHistogramFilterISS3', True, 'itk::Image< signed short,3 >'),
  ('ImageToHistogramFilter', 'itk::Statistics::ImageToHistogramFilter', 'itkImageToHistogramFilterIUC2', True, 'itk::Image< unsigned char,2 >'),
  ('ImageToHistogramFilter', 'itk::Statistics::ImageToHistogramFilter', 'itkImageToHistogramFilterIUC3', True, 'itk::Image< unsigned char,3 >'),
  ('ImageToHistogramFilter', 'itk::Statistics::ImageToHistogramFilter', 'itkImageToHistogramFilterIUS2', True, 'itk::Image< unsigned short,2 >'),
  ('ImageToHistogramFilter', 'itk::Statistics::ImageToHistogramFilter', 'itkImageToHistogramFilterIUS3', True, 'itk::Image< unsigned short,3 >'),
  ('ImageToHistogramFilter', 'itk::Statistics::ImageToHistogramFilter', 'itkImageToHistogramFilterIF2', True, 'itk::Image< float,2 >'),
  ('ImageToHistogramFilter', 'itk::Statistics::ImageToHistogramFilter', 'itkImageToHistogramFilterIF3', True, 'itk::Image< float,3 >'),
  ('ImageToHistogramFilter', 'itk::Statistics::ImageToHistogramFilter', 'itkImageToHistogramFilterID2', True, 'itk::Image< double,2 >'),
  ('ImageToHistogramFilter', 'itk::Statistics::ImageToHistogramFilter', 'itkImageToHistogramFilterID3', True, 'itk::Image< double,3 >'),
  ('ImageToHistogramFilter', 'itk::Statistics::ImageToHistogramFilter', 'itkImageToHistogramFilterICF2', True, 'itk::Image< std::complex< float >,2 >'),
  ('ImageToHistogramFilter', 'itk::Statistics::ImageToHistogramFilter', 'itkImageToHistogramFilterICF3', True, 'itk::Image< std::complex< float >,3 >'),
  ('ImageToHistogramFilter', 'itk::Statistics::ImageToHistogramFilter', 'itkImageToHistogramFilterVISS2', True, 'itk::VectorImage< signed short,2 >'),
  ('ImageToHistogramFilter', 'itk::Statistics::ImageToHistogramFilter', 'itkImageToHistogramFilterVIUC2', True, 'itk::VectorImage< unsigned char,2 >'),
  ('ImageToHistogramFilter', 'itk::Statistics::ImageToHistogramFilter', 'itkImageToHistogramFilterVIUS2', True, 'itk::VectorImage< unsigned short,2 >'),
  ('ImageToHistogramFilter', 'itk::Statistics::ImageToHistogramFilter', 'itkImageToHistogramFilterVIF2', True, 'itk::VectorImage< float,2 >'),
  ('ImageToHistogramFilter', 'itk::Statistics::ImageToHistogramFilter', 'itkImageToHistogramFilterVID2', True, 'itk::VectorImage< double,2 >'),
  ('ImageToHistogramFilter', 'itk::Statistics::ImageToHistogramFilter', 'itkImageToHistogramFilterVISS3', True, 'itk::VectorImage< signed short,3 >'),
  ('ImageToHistogramFilter', 'itk::Statistics::ImageToHistogramFilter', 'itkImageToHistogramFilterVIUC3', True, 'itk::VectorImage< unsigned char,3 >'),
  ('ImageToHistogramFilter', 'itk::Statistics::ImageToHistogramFilter', 'itkImageToHistogramFilterVIUS3', True, 'itk::VectorImage< unsigned short,3 >'),
  ('ImageToHistogramFilter', 'itk::Statistics::ImageToHistogramFilter', 'itkImageToHistogramFilterVIF3', True, 'itk::VectorImage< float,3 >'),
  ('ImageToHistogramFilter', 'itk::Statistics::ImageToHistogramFilter', 'itkImageToHistogramFilterVID3', True, 'itk::VectorImage< double,3 >'),
  ('KdTreeBasedKmeansEstimator', 'itk::Statistics::KdTreeBasedKmeansEstimator', 'itkKdTreeBasedKmeansEstimatorKdTreeLSVF2', True, 'itk::Statistics::KdTree< itk::Statistics::ListSample< itk::Vector< float,2 > > >'),
  ('KdTreeBasedKmeansEstimator', 'itk::Statistics::KdTreeBasedKmeansEstimator', 'itkKdTreeBasedKmeansEstimatorKdTreeLSVF3', True, 'itk::Statistics::KdTree< itk::Statistics::ListSample< itk::Vector< float,3 > > >'),
  ('KdTreeGenerator', 'itk::Statistics::KdTreeGenerator', 'itkKdTreeGeneratorLSVF2', True, 'itk::Statistics::ListSample< itk::Vector< float,2 > >'),
  ('KdTreeGenerator', 'itk::Statistics::KdTreeGenerator', 'itkKdTreeGeneratorLSVF3', True, 'itk::Statistics::ListSample< itk::Vector< float,3 > >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterIRGBUC2ISS2', True, 'itk::Image< itk::RGBPixel< unsigned char >,2 >, itk::Image< signed short,2 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterIRGBUC3ISS3', True, 'itk::Image< itk::RGBPixel< unsigned char >,3 >, itk::Image< signed short,3 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterIRGBUC2IUC2', True, 'itk::Image< itk::RGBPixel< unsigned char >,2 >, itk::Image< unsigned char,2 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterIRGBUC3IUC3', True, 'itk::Image< itk::RGBPixel< unsigned char >,3 >, itk::Image< unsigned char,3 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterIRGBUC2IUS2', True, 'itk::Image< itk::RGBPixel< unsigned char >,2 >, itk::Image< unsigned short,2 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterIRGBUC3IUS3', True, 'itk::Image< itk::RGBPixel< unsigned char >,3 >, itk::Image< unsigned short,3 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterIRGBAUC2ISS2', True, 'itk::Image< itk::RGBAPixel< unsigned char >,2 >, itk::Image< signed short,2 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterIRGBAUC3ISS3', True, 'itk::Image< itk::RGBAPixel< unsigned char >,3 >, itk::Image< signed short,3 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterIRGBAUC2IUC2', True, 'itk::Image< itk::RGBAPixel< unsigned char >,2 >, itk::Image< unsigned char,2 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterIRGBAUC3IUC3', True, 'itk::Image< itk::RGBAPixel< unsigned char >,3 >, itk::Image< unsigned char,3 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterIRGBAUC2IUS2', True, 'itk::Image< itk::RGBAPixel< unsigned char >,2 >, itk::Image< unsigned short,2 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterIRGBAUC3IUS3', True, 'itk::Image< itk::RGBAPixel< unsigned char >,3 >, itk::Image< unsigned short,3 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterIVF22ISS2', True, 'itk::Image< itk::Vector< float,2 >,2 >, itk::Image< signed short,2 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterIVF23ISS3', True, 'itk::Image< itk::Vector< float,2 >,3 >, itk::Image< signed short,3 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterIVF32ISS2', True, 'itk::Image< itk::Vector< float,3 >,2 >, itk::Image< signed short,2 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterIVF33ISS3', True, 'itk::Image< itk::Vector< float,3 >,3 >, itk::Image< signed short,3 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterIVF42ISS2', True, 'itk::Image< itk::Vector< float,4 >,2 >, itk::Image< signed short,2 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterIVF43ISS3', True, 'itk::Image< itk::Vector< float,4 >,3 >, itk::Image< signed short,3 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterIVF22IUC2', True, 'itk::Image< itk::Vector< float,2 >,2 >, itk::Image< unsigned char,2 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterIVF23IUC3', True, 'itk::Image< itk::Vector< float,2 >,3 >, itk::Image< unsigned char,3 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterIVF32IUC2', True, 'itk::Image< itk::Vector< float,3 >,2 >, itk::Image< unsigned char,2 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterIVF33IUC3', True, 'itk::Image< itk::Vector< float,3 >,3 >, itk::Image< unsigned char,3 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterIVF42IUC2', True, 'itk::Image< itk::Vector< float,4 >,2 >, itk::Image< unsigned char,2 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterIVF43IUC3', True, 'itk::Image< itk::Vector< float,4 >,3 >, itk::Image< unsigned char,3 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterIVF22IUS2', True, 'itk::Image< itk::Vector< float,2 >,2 >, itk::Image< unsigned short,2 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterIVF23IUS3', True, 'itk::Image< itk::Vector< float,2 >,3 >, itk::Image< unsigned short,3 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterIVF32IUS2', True, 'itk::Image< itk::Vector< float,3 >,2 >, itk::Image< unsigned short,2 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterIVF33IUS3', True, 'itk::Image< itk::Vector< float,3 >,3 >, itk::Image< unsigned short,3 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterIVF42IUS2', True, 'itk::Image< itk::Vector< float,4 >,2 >, itk::Image< unsigned short,2 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterIVF43IUS3', True, 'itk::Image< itk::Vector< float,4 >,3 >, itk::Image< unsigned short,3 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterICVF22ISS2', True, 'itk::Image< itk::CovariantVector< float,2 >,2 >, itk::Image< signed short,2 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterICVF23ISS3', True, 'itk::Image< itk::CovariantVector< float,2 >,3 >, itk::Image< signed short,3 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterICVF32ISS2', True, 'itk::Image< itk::CovariantVector< float,3 >,2 >, itk::Image< signed short,2 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterICVF33ISS3', True, 'itk::Image< itk::CovariantVector< float,3 >,3 >, itk::Image< signed short,3 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterICVF42ISS2', True, 'itk::Image< itk::CovariantVector< float,4 >,2 >, itk::Image< signed short,2 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterICVF43ISS3', True, 'itk::Image< itk::CovariantVector< float,4 >,3 >, itk::Image< signed short,3 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterICVF22IUC2', True, 'itk::Image< itk::CovariantVector< float,2 >,2 >, itk::Image< unsigned char,2 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterICVF23IUC3', True, 'itk::Image< itk::CovariantVector< float,2 >,3 >, itk::Image< unsigned char,3 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterICVF32IUC2', True, 'itk::Image< itk::CovariantVector< float,3 >,2 >, itk::Image< unsigned char,2 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterICVF33IUC3', True, 'itk::Image< itk::CovariantVector< float,3 >,3 >, itk::Image< unsigned char,3 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterICVF42IUC2', True, 'itk::Image< itk::CovariantVector< float,4 >,2 >, itk::Image< unsigned char,2 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterICVF43IUC3', True, 'itk::Image< itk::CovariantVector< float,4 >,3 >, itk::Image< unsigned char,3 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterICVF22IUS2', True, 'itk::Image< itk::CovariantVector< float,2 >,2 >, itk::Image< unsigned short,2 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterICVF23IUS3', True, 'itk::Image< itk::CovariantVector< float,2 >,3 >, itk::Image< unsigned short,3 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterICVF32IUS2', True, 'itk::Image< itk::CovariantVector< float,3 >,2 >, itk::Image< unsigned short,2 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterICVF33IUS3', True, 'itk::Image< itk::CovariantVector< float,3 >,3 >, itk::Image< unsigned short,3 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterICVF42IUS2', True, 'itk::Image< itk::CovariantVector< float,4 >,2 >, itk::Image< unsigned short,2 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterICVF43IUS3', True, 'itk::Image< itk::CovariantVector< float,4 >,3 >, itk::Image< unsigned short,3 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterISS2ISS2', True, 'itk::Image< signed short,2 >, itk::Image< signed short,2 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterISS3ISS3', True, 'itk::Image< signed short,3 >, itk::Image< signed short,3 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterISS2IUC2', True, 'itk::Image< signed short,2 >, itk::Image< unsigned char,2 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterISS3IUC3', True, 'itk::Image< signed short,3 >, itk::Image< unsigned char,3 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterISS2IUS2', True, 'itk::Image< signed short,2 >, itk::Image< unsigned short,2 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterISS3IUS3', True, 'itk::Image< signed short,3 >, itk::Image< unsigned short,3 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterIUC2ISS2', True, 'itk::Image< unsigned char,2 >, itk::Image< signed short,2 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterIUC3ISS3', True, 'itk::Image< unsigned char,3 >, itk::Image< signed short,3 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterIUC2IUC2', True, 'itk::Image< unsigned char,2 >, itk::Image< unsigned char,2 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterIUC3IUC3', True, 'itk::Image< unsigned char,3 >, itk::Image< unsigned char,3 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterIUC2IUS2', True, 'itk::Image< unsigned char,2 >, itk::Image< unsigned short,2 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterIUC3IUS3', True, 'itk::Image< unsigned char,3 >, itk::Image< unsigned short,3 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterIUS2ISS2', True, 'itk::Image< unsigned short,2 >, itk::Image< signed short,2 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterIUS3ISS3', True, 'itk::Image< unsigned short,3 >, itk::Image< signed short,3 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterIUS2IUC2', True, 'itk::Image< unsigned short,2 >, itk::Image< unsigned char,2 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterIUS3IUC3', True, 'itk::Image< unsigned short,3 >, itk::Image< unsigned char,3 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterIUS2IUS2', True, 'itk::Image< unsigned short,2 >, itk::Image< unsigned short,2 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterIUS3IUS3', True, 'itk::Image< unsigned short,3 >, itk::Image< unsigned short,3 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterIF2ISS2', True, 'itk::Image< float,2 >, itk::Image< signed short,2 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterIF3ISS3', True, 'itk::Image< float,3 >, itk::Image< signed short,3 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterIF2IUC2', True, 'itk::Image< float,2 >, itk::Image< unsigned char,2 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterIF3IUC3', True, 'itk::Image< float,3 >, itk::Image< unsigned char,3 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterIF2IUS2', True, 'itk::Image< float,2 >, itk::Image< unsigned short,2 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterIF3IUS3', True, 'itk::Image< float,3 >, itk::Image< unsigned short,3 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterID2ISS2', True, 'itk::Image< double,2 >, itk::Image< signed short,2 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterID3ISS3', True, 'itk::Image< double,3 >, itk::Image< signed short,3 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterID2IUC2', True, 'itk::Image< double,2 >, itk::Image< unsigned char,2 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterID3IUC3', True, 'itk::Image< double,3 >, itk::Image< unsigned char,3 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterID2IUS2', True, 'itk::Image< double,2 >, itk::Image< unsigned short,2 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterID3IUS3', True, 'itk::Image< double,3 >, itk::Image< unsigned short,3 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterICF2ISS2', True, 'itk::Image< std::complex< float >,2 >, itk::Image< signed short,2 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterICF3ISS3', True, 'itk::Image< std::complex< float >,3 >, itk::Image< signed short,3 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterICF2IUC2', True, 'itk::Image< std::complex< float >,2 >, itk::Image< unsigned char,2 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterICF3IUC3', True, 'itk::Image< std::complex< float >,3 >, itk::Image< unsigned char,3 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterICF2IUS2', True, 'itk::Image< std::complex< float >,2 >, itk::Image< unsigned short,2 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterICF3IUS3', True, 'itk::Image< std::complex< float >,3 >, itk::Image< unsigned short,3 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterVISS2ISS2', True, 'itk::VectorImage< signed short,2 >, itk::Image< signed short,2 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterVISS2IUC2', True, 'itk::VectorImage< signed short,2 >, itk::Image< unsigned char,2 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterVISS2IUS2', True, 'itk::VectorImage< signed short,2 >, itk::Image< unsigned short,2 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterVISS2IF2', True, 'itk::VectorImage< signed short,2 >, itk::Image< float,2 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterVISS2ID2', True, 'itk::VectorImage< signed short,2 >, itk::Image< double,2 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterVIUC2ISS2', True, 'itk::VectorImage< unsigned char,2 >, itk::Image< signed short,2 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterVIUC2IUC2', True, 'itk::VectorImage< unsigned char,2 >, itk::Image< unsigned char,2 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterVIUC2IUS2', True, 'itk::VectorImage< unsigned char,2 >, itk::Image< unsigned short,2 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterVIUC2IF2', True, 'itk::VectorImage< unsigned char,2 >, itk::Image< float,2 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterVIUC2ID2', True, 'itk::VectorImage< unsigned char,2 >, itk::Image< double,2 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterVIUS2ISS2', True, 'itk::VectorImage< unsigned short,2 >, itk::Image< signed short,2 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterVIUS2IUC2', True, 'itk::VectorImage< unsigned short,2 >, itk::Image< unsigned char,2 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterVIUS2IUS2', True, 'itk::VectorImage< unsigned short,2 >, itk::Image< unsigned short,2 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterVIUS2IF2', True, 'itk::VectorImage< unsigned short,2 >, itk::Image< float,2 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterVIUS2ID2', True, 'itk::VectorImage< unsigned short,2 >, itk::Image< double,2 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterVIF2ISS2', True, 'itk::VectorImage< float,2 >, itk::Image< signed short,2 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterVIF2IUC2', True, 'itk::VectorImage< float,2 >, itk::Image< unsigned char,2 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterVIF2IUS2', True, 'itk::VectorImage< float,2 >, itk::Image< unsigned short,2 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterVIF2IF2', True, 'itk::VectorImage< float,2 >, itk::Image< float,2 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterVIF2ID2', True, 'itk::VectorImage< float,2 >, itk::Image< double,2 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterVID2ISS2', True, 'itk::VectorImage< double,2 >, itk::Image< signed short,2 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterVID2IUC2', True, 'itk::VectorImage< double,2 >, itk::Image< unsigned char,2 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterVID2IUS2', True, 'itk::VectorImage< double,2 >, itk::Image< unsigned short,2 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterVID2IF2', True, 'itk::VectorImage< double,2 >, itk::Image< float,2 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterVID2ID2', True, 'itk::VectorImage< double,2 >, itk::Image< double,2 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterVISS3ISS3', True, 'itk::VectorImage< signed short,3 >, itk::Image< signed short,3 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterVISS3IUC3', True, 'itk::VectorImage< signed short,3 >, itk::Image< unsigned char,3 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterVISS3IUS3', True, 'itk::VectorImage< signed short,3 >, itk::Image< unsigned short,3 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterVISS3IF3', True, 'itk::VectorImage< signed short,3 >, itk::Image< float,3 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterVISS3ID3', True, 'itk::VectorImage< signed short,3 >, itk::Image< double,3 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterVIUC3ISS3', True, 'itk::VectorImage< unsigned char,3 >, itk::Image< signed short,3 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterVIUC3IUC3', True, 'itk::VectorImage< unsigned char,3 >, itk::Image< unsigned char,3 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterVIUC3IUS3', True, 'itk::VectorImage< unsigned char,3 >, itk::Image< unsigned short,3 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterVIUC3IF3', True, 'itk::VectorImage< unsigned char,3 >, itk::Image< float,3 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterVIUC3ID3', True, 'itk::VectorImage< unsigned char,3 >, itk::Image< double,3 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterVIUS3ISS3', True, 'itk::VectorImage< unsigned short,3 >, itk::Image< signed short,3 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterVIUS3IUC3', True, 'itk::VectorImage< unsigned short,3 >, itk::Image< unsigned char,3 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterVIUS3IUS3', True, 'itk::VectorImage< unsigned short,3 >, itk::Image< unsigned short,3 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterVIUS3IF3', True, 'itk::VectorImage< unsigned short,3 >, itk::Image< float,3 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterVIUS3ID3', True, 'itk::VectorImage< unsigned short,3 >, itk::Image< double,3 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterVIF3ISS3', True, 'itk::VectorImage< float,3 >, itk::Image< signed short,3 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterVIF3IUC3', True, 'itk::VectorImage< float,3 >, itk::Image< unsigned char,3 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterVIF3IUS3', True, 'itk::VectorImage< float,3 >, itk::Image< unsigned short,3 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterVIF3IF3', True, 'itk::VectorImage< float,3 >, itk::Image< float,3 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterVIF3ID3', True, 'itk::VectorImage< float,3 >, itk::Image< double,3 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterVID3ISS3', True, 'itk::VectorImage< double,3 >, itk::Image< signed short,3 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterVID3IUC3', True, 'itk::VectorImage< double,3 >, itk::Image< unsigned char,3 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterVID3IUS3', True, 'itk::VectorImage< double,3 >, itk::Image< unsigned short,3 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterVID3IF3', True, 'itk::VectorImage< double,3 >, itk::Image< float,3 >'),
  ('MaskedImageToHistogramFilter', 'itk::Statistics::MaskedImageToHistogramFilter', 'itkMaskedImageToHistogramFilterVID3ID3', True, 'itk::VectorImage< double,3 >, itk::Image< double,3 >'),
  ('NormalVariateGenerator', 'itk::Statistics::NormalVariateGenerator', 'itkNormalVariateGenerator', True),
  ('ScalarImageToCooccurrenceMatrixFilter', 'itk::Statistics::ScalarImageToCooccurrenceMatrixFilter', 'itkScalarImageToCooccurrenceMatrixFilterISS2', True, 'itk::Image< signed short,2 >'),
  ('ScalarImageToCooccurrenceMatrixFilter', 'itk::Statistics::ScalarImageToCooccurrenceMatrixFilter', 'itkScalarImageToCooccurrenceMatrixFilterISS3', True, 'itk::Image< signed short,3 >'),
  ('ScalarImageToCooccurrenceMatrixFilter', 'itk::Statistics::ScalarImageToCooccurrenceMatrixFilter', 'itkScalarImageToCooccurrenceMatrixFilterIUC2', True, 'itk::Image< unsigned char,2 >'),
  ('ScalarImageToCooccurrenceMatrixFilter', 'itk::Statistics::ScalarImageToCooccurrenceMatrixFilter', 'itkScalarImageToCooccurrenceMatrixFilterIUC3', True, 'itk::Image< unsigned char,3 >'),
  ('ScalarImageToCooccurrenceMatrixFilter', 'itk::Statistics::ScalarImageToCooccurrenceMatrixFilter', 'itkScalarImageToCooccurrenceMatrixFilterIUS2', True, 'itk::Image< unsigned short,2 >'),
  ('ScalarImageToCooccurrenceMatrixFilter', 'itk::Statistics::ScalarImageToCooccurrenceMatrixFilter', 'itkScalarImageToCooccurrenceMatrixFilterIUS3', True, 'itk::Image< unsigned short,3 >'),
  ('ScalarImageToCooccurrenceMatrixFilter', 'itk::Statistics::ScalarImageToCooccurrenceMatrixFilter', 'itkScalarImageToCooccurrenceMatrixFilterIF2', True, 'itk::Image< float,2 >'),
  ('ScalarImageToCooccurrenceMatrixFilter', 'itk::Statistics::ScalarImageToCooccurrenceMatrixFilter', 'itkScalarImageToCooccurrenceMatrixFilterIF3', True, 'itk::Image< float,3 >'),
  ('ScalarImageToCooccurrenceMatrixFilter', 'itk::Statistics::ScalarImageToCooccurrenceMatrixFilter', 'itkScalarImageToCooccurrenceMatrixFilterID2', True, 'itk::Image< double,2 >'),
  ('ScalarImageToCooccurrenceMatrixFilter', 'itk::Statistics::ScalarImageToCooccurrenceMatrixFilter', 'itkScalarImageToCooccurrenceMatrixFilterID3', True, 'itk::Image< double,3 >'),
  ('ScalarImageToHistogramGenerator', 'itk::Statistics::ScalarImageToHistogramGenerator', 'itkScalarImageToHistogramGeneratorISS2', True, 'itk::Image< signed short,2 >'),
  ('ScalarImageToHistogramGenerator', 'itk::Statistics::ScalarImageToHistogramGenerator', 'itkScalarImageToHistogramGeneratorISS3', True, 'itk::Image< signed short,3 >'),
  ('ScalarImageToHistogramGenerator', 'itk::Statistics::ScalarImageToHistogramGenerator', 'itkScalarImageToHistogramGeneratorIUC2', True, 'itk::Image< unsigned char,2 >'),
  ('ScalarImageToHistogramGenerator', 'itk::Statistics::ScalarImageToHistogramGenerator', 'itkScalarImageToHistogramGeneratorIUC3', True, 'itk::Image< unsigned char,3 >'),
  ('ScalarImageToHistogramGenerator', 'itk::Statistics::ScalarImageToHistogramGenerator', 'itkScalarImageToHistogramGeneratorIUS2', True, 'itk::Image< unsigned short,2 >'),
  ('ScalarImageToHistogramGenerator', 'itk::Statistics::ScalarImageToHistogramGenerator', 'itkScalarImageToHistogramGeneratorIUS3', True, 'itk::Image< unsigned short,3 >'),
  ('ScalarImageToHistogramGenerator', 'itk::Statistics::ScalarImageToHistogramGenerator', 'itkScalarImageToHistogramGeneratorIF2', True, 'itk::Image< float,2 >'),
  ('ScalarImageToHistogramGenerator', 'itk::Statistics::ScalarImageToHistogramGenerator', 'itkScalarImageToHistogramGeneratorIF3', True, 'itk::Image< float,3 >'),
  ('ScalarImageToHistogramGenerator', 'itk::Statistics::ScalarImageToHistogramGenerator', 'itkScalarImageToHistogramGeneratorID2', True, 'itk::Image< double,2 >'),
  ('ScalarImageToHistogramGenerator', 'itk::Statistics::ScalarImageToHistogramGenerator', 'itkScalarImageToHistogramGeneratorID3', True, 'itk::Image< double,3 >'),
  ('ScalarImageToRunLengthFeaturesFilter', 'itk::Statistics::ScalarImageToRunLengthFeaturesFilter', 'itkScalarImageToRunLengthFeaturesFilterISS2', True, 'itk::Image< signed short,2 >'),
  ('ScalarImageToRunLengthFeaturesFilter', 'itk::Statistics::ScalarImageToRunLengthFeaturesFilter', 'itkScalarImageToRunLengthFeaturesFilterISS3', True, 'itk::Image< signed short,3 >'),
  ('ScalarImageToRunLengthFeaturesFilter', 'itk::Statistics::ScalarImageToRunLengthFeaturesFilter', 'itkScalarImageToRunLengthFeaturesFilterIUC2', True, 'itk::Image< unsigned char,2 >'),
  ('ScalarImageToRunLengthFeaturesFilter', 'itk::Statistics::ScalarImageToRunLengthFeaturesFilter', 'itkScalarImageToRunLengthFeaturesFilterIUC3', True, 'itk::Image< unsigned char,3 >'),
  ('ScalarImageToRunLengthFeaturesFilter', 'itk::Statistics::ScalarImageToRunLengthFeaturesFilter', 'itkScalarImageToRunLengthFeaturesFilterIUS2', True, 'itk::Image< unsigned short,2 >'),
  ('ScalarImageToRunLengthFeaturesFilter', 'itk::Statistics::ScalarImageToRunLengthFeaturesFilter', 'itkScalarImageToRunLengthFeaturesFilterIUS3', True, 'itk::Image< unsigned short,3 >'),
  ('ScalarImageToRunLengthFeaturesFilter', 'itk::Statistics::ScalarImageToRunLengthFeaturesFilter', 'itkScalarImageToRunLengthFeaturesFilterIF2', True, 'itk::Image< float,2 >'),
  ('ScalarImageToRunLengthFeaturesFilter', 'itk::Statistics::ScalarImageToRunLengthFeaturesFilter', 'itkScalarImageToRunLengthFeaturesFilterIF3', True, 'itk::Image< float,3 >'),
  ('ScalarImageToRunLengthFeaturesFilter', 'itk::Statistics::ScalarImageToRunLengthFeaturesFilter', 'itkScalarImageToRunLengthFeaturesFilterID2', True, 'itk::Image< double,2 >'),
  ('ScalarImageToRunLengthFeaturesFilter', 'itk::Statistics::ScalarImageToRunLengthFeaturesFilter', 'itkScalarImageToRunLengthFeaturesFilterID3', True, 'itk::Image< double,3 >'),
  ('ScalarImageToRunLengthMatrixFilter', 'itk::Statistics::ScalarImageToRunLengthMatrixFilter', 'itkScalarImageToRunLengthMatrixFilterISS2', True, 'itk::Image< signed short,2 >'),
  ('ScalarImageToRunLengthMatrixFilter', 'itk::Statistics::ScalarImageToRunLengthMatrixFilter', 'itkScalarImageToRunLengthMatrixFilterISS3', True, 'itk::Image< signed short,3 >'),
  ('ScalarImageToRunLengthMatrixFilter', 'itk::Statistics::ScalarImageToRunLengthMatrixFilter', 'itkScalarImageToRunLengthMatrixFilterIUC2', True, 'itk::Image< unsigned char,2 >'),
  ('ScalarImageToRunLengthMatrixFilter', 'itk::Statistics::ScalarImageToRunLengthMatrixFilter', 'itkScalarImageToRunLengthMatrixFilterIUC3', True, 'itk::Image< unsigned char,3 >'),
  ('ScalarImageToRunLengthMatrixFilter', 'itk::Statistics::ScalarImageToRunLengthMatrixFilter', 'itkScalarImageToRunLengthMatrixFilterIUS2', True, 'itk::Image< unsigned short,2 >'),
  ('ScalarImageToRunLengthMatrixFilter', 'itk::Statistics::ScalarImageToRunLengthMatrixFilter', 'itkScalarImageToRunLengthMatrixFilterIUS3', True, 'itk::Image< unsigned short,3 >'),
  ('ScalarImageToRunLengthMatrixFilter', 'itk::Statistics::ScalarImageToRunLengthMatrixFilter', 'itkScalarImageToRunLengthMatrixFilterIF2', True, 'itk::Image< float,2 >'),
  ('ScalarImageToRunLengthMatrixFilter', 'itk::Statistics::ScalarImageToRunLengthMatrixFilter', 'itkScalarImageToRunLengthMatrixFilterIF3', True, 'itk::Image< float,3 >'),
  ('ScalarImageToRunLengthMatrixFilter', 'itk::Statistics::ScalarImageToRunLengthMatrixFilter', 'itkScalarImageToRunLengthMatrixFilterID2', True, 'itk::Image< double,2 >'),
  ('ScalarImageToRunLengthMatrixFilter', 'itk::Statistics::ScalarImageToRunLengthMatrixFilter', 'itkScalarImageToRunLengthMatrixFilterID3', True, 'itk::Image< double,3 >'),
  ('ScalarImageToTextureFeaturesFilter', 'itk::Statistics::ScalarImageToTextureFeaturesFilter', 'itkScalarImageToTextureFeaturesFilterISS2', True, 'itk::Image< signed short,2 >'),
  ('ScalarImageToTextureFeaturesFilter', 'itk::Statistics::ScalarImageToTextureFeaturesFilter', 'itkScalarImageToTextureFeaturesFilterISS3', True, 'itk::Image< signed short,3 >'),
  ('ScalarImageToTextureFeaturesFilter', 'itk::Statistics::ScalarImageToTextureFeaturesFilter', 'itkScalarImageToTextureFeaturesFilterIUC2', True, 'itk::Image< unsigned char,2 >'),
  ('ScalarImageToTextureFeaturesFilter', 'itk::Statistics::ScalarImageToTextureFeaturesFilter', 'itkScalarImageToTextureFeaturesFilterIUC3', True, 'itk::Image< unsigned char,3 >'),
  ('ScalarImageToTextureFeaturesFilter', 'itk::Statistics::ScalarImageToTextureFeaturesFilter', 'itkScalarImageToTextureFeaturesFilterIUS2', True, 'itk::Image< unsigned short,2 >'),
  ('ScalarImageToTextureFeaturesFilter', 'itk::Statistics::ScalarImageToTextureFeaturesFilter', 'itkScalarImageToTextureFeaturesFilterIUS3', True, 'itk::Image< unsigned short,3 >'),
  ('ScalarImageToTextureFeaturesFilter', 'itk::Statistics::ScalarImageToTextureFeaturesFilter', 'itkScalarImageToTextureFeaturesFilterIF2', True, 'itk::Image< float,2 >'),
  ('ScalarImageToTextureFeaturesFilter', 'itk::Statistics::ScalarImageToTextureFeaturesFilter', 'itkScalarImageToTextureFeaturesFilterIF3', True, 'itk::Image< float,3 >'),
  ('ScalarImageToTextureFeaturesFilter', 'itk::Statistics::ScalarImageToTextureFeaturesFilter', 'itkScalarImageToTextureFeaturesFilterID2', True, 'itk::Image< double,2 >'),
  ('ScalarImageToTextureFeaturesFilter', 'itk::Statistics::ScalarImageToTextureFeaturesFilter', 'itkScalarImageToTextureFeaturesFilterID3', True, 'itk::Image< double,3 >'),
  ('WeightedCentroidKdTreeGenerator', 'itk::Statistics::WeightedCentroidKdTreeGenerator', 'itkWeightedCentroidKdTreeGeneratorLSVF2', True, 'itk::Statistics::ListSample< itk::Vector< float,2 > >'),
  ('WeightedCentroidKdTreeGenerator', 'itk::Statistics::WeightedCentroidKdTreeGenerator', 'itkWeightedCentroidKdTreeGeneratorLSVF3', True, 'itk::Statistics::ListSample< itk::Vector< float,3 > >'),
)
snake_case_functions = ('histogram_to_texture_features_filter', 'histogram_to_log_probability_image_filter', 'histogram_to_run_length_features_filter', 'scalar_image_to_run_length_matrix_filter', 'scalar_image_to_texture_features_filter', 'histogram_to_intensity_image_filter', 'scalar_image_to_cooccurrence_matrix_filter', 'image_to_histogram_filter', 'scalar_image_to_run_length_features_filter', 'histogram_to_entropy_image_filter', 'histogram_to_image_filter', 'masked_image_to_histogram_filter', 'histogram_to_probability_image_filter', )
